@@ -7,7 +7,7 @@
 
 """Classes to represent a KGML Pathway Map.
 
-The KGML definition is as of release KGML v0.7.1
+The KGML definition is as of release KGML v0.7.2
 (http://www.kegg.jp/kegg/xml/docs/)
 
 Classes:
@@ -27,15 +27,13 @@ from itertools import chain
 from xml.dom import minidom
 import xml.etree.ElementTree as ET
 
-from Bio._py3k import _is_int_or_long, _as_string
-
 
 # Pathway
-class Pathway(object):
+class Pathway:
     """Represents a KGML pathway from KEGG.
 
     Specifies graph information for the pathway map, as described in
-    release KGML v0.7.1 (http://www.kegg.jp/kegg/xml/docs/)
+    release KGML v0.7.2 (http://www.kegg.jp/kegg/xml/docs/)
 
     Attributes:
      - name - KEGGID of the pathway map
@@ -83,18 +81,18 @@ class Pathway(object):
                 '<?xml version="1.0"?>',
                 "<!DOCTYPE pathway SYSTEM "
                 '"http://www.genome.jp/kegg/xml/'
-                'KGML_v0.7.1_.dtd">',
+                'KGML_v0.7.2_.dtd">',
                 "<!-- Created by KGML_Pathway.py %s -->" % time.asctime(),
             ]
         )
-        rough_xml = header + _as_string(ET.tostring(self.element, "utf-8"))
+        rough_xml = header + ET.tostring(self.element, "utf-8").decode()
         reparsed = minidom.parseString(rough_xml)
         return reparsed.toprettyxml(indent="  ")
 
     def add_entry(self, entry):
         """Add an Entry element to the pathway."""
         # We insist that the node ID is an integer
-        if not _is_int_or_long(entry.id):
+        if not isinstance(entry.id, int):
             raise TypeError(
                 "Node ID must be an integer, got %s (%s)" % (type(entry.id), entry.id)
             )
@@ -103,7 +101,7 @@ class Pathway(object):
 
     def remove_entry(self, entry):
         """Remove an Entry element from the pathway."""
-        if not _is_int_or_long(entry.id):
+        if not isinstance(entry.id, int):
             raise TypeError(
                 "Node ID must be an integer, got %s (%s)" % (type(entry.id), entry.id)
             )
@@ -115,21 +113,19 @@ class Pathway(object):
     def add_reaction(self, reaction):
         """Add a Reaction element to the pathway."""
         # We insist that the node ID is an integer and corresponds to an entry
-        if not _is_int_or_long(reaction.id):
+        if not isinstance(reaction.id, int):
             raise ValueError(
                 "Node ID must be an integer, got %s (%s)"
                 % (type(reaction.id), reaction.id)
             )
         if reaction.id not in self.entries:
-            raise ValueError(
-                "Reaction ID %d has no corresponding entry" % reaction.id
-            )
+            raise ValueError("Reaction ID %d has no corresponding entry" % reaction.id)
         reaction._pathway = self  # Let the reaction know about the pathway
         self._reactions[reaction.id] = reaction
 
     def remove_reaction(self, reaction):
         """Remove a Reaction element from the pathway."""
-        if not _is_int_or_long(reaction.id):
+        if not isinstance(reaction.id, int):
             raise TypeError(
                 "Node ID must be an integer, got %s (%s)"
                 % (type(reaction.id), reaction.id)
@@ -170,9 +166,7 @@ class Pathway(object):
 
     def _setname(self, value):
         if not value.startswith("path:"):
-            raise ValueError(
-                "Pathway name should begin with 'path:', got %s" % value
-            )
+            raise ValueError("Pathway name should begin with 'path:', got %s" % value)
         self._name = value
 
     def _delname(self):
@@ -264,11 +258,11 @@ class Pathway(object):
 
 
 # Entry
-class Entry(object):
+class Entry:
     """Represent an Entry from KGML.
 
     Each Entry element is a node in the pathway graph, as described in
-    release KGML v0.7.1 (http://www.kegg.jp/kegg/xml/docs/)
+    release KGML v0.7.2 (http://www.kegg.jp/kegg/xml/docs/)
 
     Attributes:
      - id - The ID of the entry in the pathway map (integer)
@@ -424,11 +418,11 @@ class Entry(object):
 
 
 # Component
-class Component(object):
+class Component:
     """An Entry subelement used to represents a complex node.
 
     A subelement of the Entry element, used when the Entry is a complex
-    node, as described in release KGML v0.7.1
+    node, as described in release KGML v0.7.2
     (http://www.kegg.jp/kegg/xml/docs/)
 
     The Component acts as a collection (with type 'group', and typically
@@ -462,11 +456,11 @@ class Component(object):
 
 
 # Graphics
-class Graphics(object):
+class Graphics:
     """An Entry subelement used to represents the visual representation.
 
     A subelement of Entry, specifying its visual representation, as
-    described in release KGML v0.7.1 (http://www.kegg.jp/kegg/xml/docs/)
+    described in release KGML v0.7.2 (http://www.kegg.jp/kegg/xml/docs/)
 
     Attributes:
      - name         Label for the graphics object
@@ -658,7 +652,7 @@ class Graphics(object):
 
 
 # Reaction
-class Reaction(object):
+class Reaction:
     """A specific chemical reaction with substrates and products.
 
     This describes a specific chemical reaction between one or more
@@ -782,11 +776,11 @@ class Reaction(object):
 
 
 # Relation
-class Relation(object):
+class Relation:
     """A relationship between to products, KOs, or protein and compound.
 
     This describes a relationship between two products, KOs, or protein
-    and compound, as described in release KGML v0.7.1
+    and compound, as described in release KGML v0.7.2
     (http://www.kegg.jp/kegg/xml/docs/)
 
     Attributes:
@@ -860,6 +854,6 @@ class Relation(object):
         }
         for (name, value) in self.subtypes:
             subtype = ET.Element("subtype")
-            subtype.attrib[name] = str(value)
+            subtype.attrib = {"name": name, "value": str(value)}
             relation.append(subtype)
         return relation
